# Publishing a Python package

[![CircleCI](https://circleci.com/gh/CIRCLECI-GWP/publish-python-package.svg?style=svg)](https://circleci.com/gh/CIRCLECI-GWP/publish-python-package)

<p align="center"><img src="https://avatars3.githubusercontent.com/u/59034516"></p>

- Blog post: [Publishing a python package][blog]

### About CircleCI Guest Writer Program

Join a team of freelance writers and write about your favorite technology topics for the CircleCI blog. Read more about the program [here][gwp-program].

[blog]: https://circleci.com/blog/publishing-a-python-package/
[gwp-program]: https://circle.ci/3ahQxfu
